@@ -18,15 +18,16 @@ NOTE_OFF = 0
 class Event(object):
 
 
-    __slots__ = [ 'type', 'note', 'time', 'on_event', 'scale' ]
+    __slots__ = [ 'type', 'note', 'time', 'on_event', 'scale', 'from_context' ]
 
     from . note import Note
 
-    def __init__(self, type=None, note=None, time=None, on_event=None, scale=None, muted=False, track_copy=False):
+    def __init__(self, type=None, note=None, time=None, on_event=None, scale=None, from_context=None):
         self.type = type
         self.note = note
         self.time = time
         self.on_event = on_event
+        self.from_context = from_context
         self.scale = scale
 
     def __repr__(self):
