@@ -9,28 +9,37 @@
 
 from .base import NewReferenceObject
 from .instrument import Instrument
+from warpseq.utils.serialization import Serializer
 
 class Track(NewReferenceObject):
 
     __slots__ = [ 'name', 'muted', 'instrument', 'instruments', 'clip_ids', 'obj_id' ]
 
+    SERIALIZER = Serializer(
+        values = ( 'name', 'muted', 'clip_ids' ),
+        objects = ( 'instrument' ),
+        object_lists = ( 'instruments' ),
+        objects_2d = (),
+        custom=(),
+    )
+
     def __init__(self, name=None, muted=False, instrument=None, instruments=None, clip_ids=None, obj_id=None):
+
         self.name = name
         self.muted = muted
+        self.obj_id = obj_id
 
         if instruments is None:
             instruments = []
         self.instruments = instruments
 
-        if instrument is not None:
-            # legacy support argument mapping to new "instruments"
-            self.instruments.append(instrument)
-
+        if clip_ids is None:
+            clip_ids = []
         self.clip_ids = clip_ids
-        self.obj_id = obj_id
 
-        if self.clip_ids is None:
-            self.clip_ids = []
+        # backwards compat: new usage should use "instruments"
+        if instrument is not None:
+            self.instruments.append(instrument)
 
         super(Track, self).__init__()
 
@@ -39,49 +48,12 @@ class Track(NewReferenceObject):
         return self.instruments
 
     def has_clip(self, clip):
-        """
-        Is this clip part of this track?
-        """
-        assert clip is not None
         return clip.obj_id in self.clip_ids
 
     def add_clip(self, clip):
-        """
-        Adds a clip to a track.  Use from song.py - not directly.
-        """
-        assert clip is not None
         if clip.obj_id not in self.clip_ids:
             self.clip_ids.append(clip.obj_id)
 
     def remove_clip(self, clip):
-        """
-        Remove a clip from this track. Use from song.py - not directly.
-        """
-        assert clip is not None
         self.clip_ids = [ c for c in self.clip_ids if c != clip.obj_id ]
 
-    def to_dict(self):
-        data = dict(
-            obj_id = self.obj_id,
-            name = self.name,
-            muted = self.muted,
-            instruments = [ x.obj_id for x in self.instruments ],
-            clip_ids = self.clip_ids,
-        )
-        return data
-
-
-    @classmethod
-    def from_dict(cls, song, data):
-
-        instrument = song.find_instrument(data['instrument'])
-        assert instrument is not None
-
-
-        return Track(
-            obj_id = data['obj_id'],
-            name = data['name'],
-            muted = data['muted'],
-            instruments = [ song.find_instrument(x) for x in data.get('instruments', []) ],
-            clip_ids = data['clip_ids']
-        )
