@@ -12,6 +12,7 @@ from .base import NewReferenceObject
 from .directions import *
 from warpseq.utils.serialization import Serializer
 from warpseq.model.context import Context
+from warpseq.model.slot import Slot
 
 CHORDS = 'chords'
 NOTES = 'notes'
@@ -36,6 +37,10 @@ class Transform(NewReferenceObject, Directionable):
 
         self.name = name
         self.slots = slots
+
+        for x in slots:
+            assert isinstance(x, Slot)
+
         self.divide = divide
         self.applies_to = applies_to
         self.obj_id = obj_id
@@ -49,6 +54,8 @@ class Transform(NewReferenceObject, Directionable):
             applies_to = BOTH
         self.applies_to = applies_to
 
+
+
         assert applies_to in APPLIES_CHOICES
         self.reset()
 
