@@ -12,9 +12,10 @@
 
 from ..api.callbacks import Callbacks
 from ..api.exceptions import *
-from ..model.event import NOTE_OFF, NOTE_ON, Event
-import time
-from .. notation.time_stream import NOTE_GAP
+from ..model.event import NOTE_OFF, Event
+from warpseq.model.time_stream import NOTE_GAP
+import traceback
+
 
 def event_sorter(evt):
     return evt.time
