@@ -15,7 +15,6 @@ from warpseq.model.registers import register_playing_note, unregister_playing_no
 from warpseq.playback.midi import midi_note_on, midi_note_off, midi_cc
 from warpseq.model.chord import Chord
 from warpseq.model.event import Event, NOTE_OFF, NOTE_ON
-from warpseq.model.context import Context
 
 def _get_note_number(note, instrument):
 
@@ -32,15 +31,15 @@ def _get_note_number(note, instrument):
     nn = note2.note_number()
 
     if nn < 0 or nn > 127:
-        print("NOTE: %s" % note)
-        raise InvalidNote()
+        print("warning: note outside of playable range: %s" % note)
+        return None
 
     return nn
 
 
 class RealtimeEngine(object):
 
-    __slots__ = ['song','track','clip','midi_out','midi_port','mod_expressions','callbacks','on_count','player','context']
+    __slots__ = ['song','track','clip','midi_out','midi_port','mod_expressions','callbacks','on_count','player']
 
     def __init__(self, song=None, track=None, clip=None, player=None):
         self.song = song
@@ -48,12 +47,6 @@ class RealtimeEngine(object):
         self.clip = clip
         self.player = player
         self.callbacks = Callbacks()
-        self.context = Context(
-            player = self.player,
-            clip = self.clip,
-            track = self.track,
-            song = self.song,
-        )
 
     def play(self, event):
 
@@ -67,17 +60,17 @@ class RealtimeEngine(object):
 
         cb = pattern.mod_expressions_callback # this must be a generator
 
-        if event.type == NOTE_ON and (cb or event.note.deferred == True):
+        if event.type == NOTE_ON:
 
             # we have to process deferred expressions twice because of the mod events
             # UNLESS we pair the off event.
 
-            self.context.scale = event.scale
-            self.context.pattern = event.from_context.pattern
+            #self.context.scale = event.scale
+            #self.context.pattern = event.from_context.pattern
 
             exprs = event.note.deferred_expressions
             for expr in exprs:
-                value = expr.evaluate(context, note)
+                value = expr.evaluate(self.track, event.note)
                 if value is None:
                     return
                 event.note = value
@@ -86,7 +79,7 @@ class RealtimeEngine(object):
             if cb is not None:
                 new_mod_expressions = next(cb)
                 for expr in new_mod_expressions:
-                    event.note = expr.evaluate(context, event.note)
+                    event.note = expr.evaluate(self.track, event.note)
                     if event.note is None:
                         return
                     event.note = value
